#
# spec file for package megatools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global snapshot 20230212

Name:           megatools
Version:        1.11.1
Release:        1.4
Summary:        CLI client for mega.co.nz
License:        GPL-2.0-or-later
Group:          Productivity/Networking/File-Sharing
URL:            http://megatools.megous.com
Source0:        %{name}-%{version}.%{snapshot}.tar.gz
Source1:        %{name}-%{version}.%{snapshot}.tar.gz.asc
# Keyring obtained from https://xff.cz/key.txt
Source2:        %{name}.keyring
BuildRequires:  asciidoc
BuildRequires:  docbook2X
BuildRequires:  fuse-devel
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  libcurl-devel >= 7.85.0
BuildRequires:  libopenssl-devel
BuildRequires:  meson
Requires:       curl >= 7.85.0
Requires:       fuse
Requires:       glib-networking >= 2.32.0
Requires:       openssl

%description	-n %{name}
Megatools allow you to copy individual files as well as entire directory trees
to and from the cloud. You can also perform streaming downloads for example to
preview videos and audio files, without needing to download the entire file.
 
You can register an account using a "megareg" tool, with the benefit of having
true control of your encryption keys.
 
Megatools are robust and optimized for fast operation - as fast as Mega servers
allow. Memory requirements and CPU utilization are kept at minimum.

%prep
%autosetup -n %{name}-%{version}.%{snapshot}
 
%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test
%ldconfig_scriptlets

%files
%license LICENSE
%doc NEWS README
%{_bindir}/mega*
%{_mandir}/man1/mega*.1.*
%{_mandir}/man5/mega*.5.*
%exclude %{_datadir}/doc/%{name}/*

%changelog
* Thu Mar 16 2023 Luiz Fernando Ranghetti <elchevive@opensuse.org>
- updated to 1.11.1
- updated minimal curl required to 7.85.0
  * Improvements/Fixes:
  - Megatools now install a single `megatools` executable, where former
    `megaXYZ ...` commands now have to be executed as `megatools XYZ ...`.
  - Implemented PKP (public key pinning for mega.nz's API server). Megatools
    no longer use public certificate authorities to verify API server's
    authenticity. If you use software that MITM's your web traffic, megatools
    will not allow this anymore.
  - Support new public folder URLs in `dl`
  - Build system moved to meson
  - New `test` command for checking if file exists
  - New `export` command for creating public links for private files
  - Login v2 support
  - fix folder downloads
  - fix handling of = in mega URLs
* Mon Jun 29 2020 Adrian Strauss <astrokyttaros@pm.me>
- updated to 1.10.3
- updated keyring file to new public key
- specified GPL2 version
* Fri Jul 21 2017 petr@cervinka.net
  * Updated to version 1.9.98
  - spec file cleaned
  - removed libmega and devel packages (upstream change)
  - new build requirement asciidoc
  - updated keyring file with correct public key 0x77CFEFF1
  * New features:
  - Support upload/download speed limit settings
  - Support socks proxy
  - Improved progress reporting
  - Support for OpenSSL 1.1.x
  * Removals:
  - Remove undocummented --abort-on-error option. Tools now always
    report errors through exit status.
  - Remove libmega.so public library support and a lot of unused code
    that was planned to be used for 2.0
  - Remove megamv (it was never implemented and confused users)
  - Remove megafs (it was just an experiment and confused users)
  * Cleanups:
  - Cleanup build system a bit
  - Cleanup CLI option handling, improved --help output
  * Fixes:
  - Enable automatic decompression (CURLOPT_ACCEPT_ENCODING) (by protomouse)
    (This finally fixes the problem with HTTP compression.)
  - Exit status from all the tools is now correctly reported
  - Fix syncing of symlinked files
  - Support very long passwords in the password prompt (up to 1024 chars)
* Wed Apr 20 2016 sleep_walker@opensuse.org
- bump to 1.9.97, bugfix release
- move libmega0 to separate subpackage
* Fri Oct  9 2015 sleep_walker@opensuse.org
- add keyring
* Thu Aug  6 2015 sleep_walker@opensuse.org
- remove static libraries
- clean-up the spec file manually and with spec-cleaner
* Thu Jul 30 2015 yoshi314+obs@gmail.com
- bump to 1.9.95
* Fri Oct 24 2014 oleg@grodno.ru
- Update to version 1.9.93
* Mon Aug 25 2014 oleg@grodno.ru
  Updated to version 1.9.92
* Sat Jul  6 2013 oleg@grodno.ru
  Megatools 1.9.91 released with bugfixes and all new man pages.
